==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/RawIPSetFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RawIPSetFluentImpl<A extends RawIPSetFluent<A>> extends BaseFluent<A> implements RawIPSetFluent<A>{
  public RawIPSetFluentImpl() {
  }
  public RawIPSetFluentImpl(RawIPSet instance) {
    this.withCidrs(instance.getCidrs()); 
    this.withName(instance.getName()); 
    this.withSource(instance.getSource()); 
  }
  private List<String> cidrs = new ArrayList<String>();
  private String name;
  private String source;
  public A addToCidrs(Integer index,String item) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    this.cidrs.add(index, item);
    return (A)this;
  }
  public A setToCidrs(Integer index,String item) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    this.cidrs.set(index, item); return (A)this;
  }
  public A addToCidrs(java.lang.String... items) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    for (String item : items) {this.cidrs.add(item);} return (A)this;
  }
  public A addAllToCidrs(Collection<String> items) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    for (String item : items) {this.cidrs.add(item);} return (A)this;
  }
  public A removeFromCidrs(java.lang.String... items) {
    for (String item : items) {if (this.cidrs!= null){ this.cidrs.remove(item);}} return (A)this;
  }
  public A removeAllFromCidrs(Collection<String> items) {
    for (String item : items) {if (this.cidrs!= null){ this.cidrs.remove(item);}} return (A)this;
  }
  public List<String> getCidrs() {
    return this.cidrs;
  }
  public String getCidr(Integer index) {
    return this.cidrs.get(index);
  }
  public String getFirstCidr() {
    return this.cidrs.get(0);
  }
  public String getLastCidr() {
    return this.cidrs.get(cidrs.size() - 1);
  }
  public String getMatchingCidr(Predicate<String> predicate) {
    for (String item: cidrs) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingCidr(Predicate<String> predicate) {
    for (String item: cidrs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCidrs(List<String> cidrs) {
    if (cidrs != null) {this.cidrs = new ArrayList(); for (String item : cidrs){this.addToCidrs(item);}} else { this.cidrs = null;} return (A) this;
  }
  public A withCidrs(java.lang.String... cidrs) {
    if (this.cidrs != null) {this.cidrs.clear();}
    if (cidrs != null) {for (String item :cidrs){ this.addToCidrs(item);}} return (A) this;
  }
  public Boolean hasCidrs() {
    return cidrs != null && !cidrs.isEmpty();
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RawIPSetFluentImpl that = (RawIPSetFluentImpl) o;
    if (cidrs != null ? !cidrs.equals(that.cidrs) :that.cidrs != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidrs,  name,  source,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidrs != null && !cidrs.isEmpty()) { sb.append("cidrs:"); sb.append(cidrs + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/RawIPSetFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RawIPSetFluentImpl<A extends RawIPSetFluent<A>> extends BaseFluent<A> implements RawIPSetFluent<A>{
  public RawIPSetFluentImpl() {
  }
  public RawIPSetFluentImpl(RawIPSet instance) {
    if (instance != null) {
      this.withCidrs(instance.getCidrs());
      this.withName(instance.getName());
      this.withSource(instance.getSource());
    }
  }
  private List<String> cidrs = new ArrayList<String>();
  private String name;
  private String source;
  public A addToCidrs(int index,String item) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    this.cidrs.add(index, item);
    return (A)this;
  }
  public A setToCidrs(int index,String item) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    this.cidrs.set(index, item); return (A)this;
  }
  public A addToCidrs(java.lang.String... items) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    for (String item : items) {this.cidrs.add(item);} return (A)this;
  }
  public A addAllToCidrs(Collection<String> items) {
    if (this.cidrs == null) {this.cidrs = new ArrayList<String>();}
    for (String item : items) {this.cidrs.add(item);} return (A)this;
  }
  public A removeFromCidrs(java.lang.String... items) {
    for (String item : items) {if (this.cidrs!= null){ this.cidrs.remove(item);}} return (A)this;
  }
  public A removeAllFromCidrs(Collection<String> items) {
    for (String item : items) {if (this.cidrs!= null){ this.cidrs.remove(item);}} return (A)this;
  }
  public List<String> getCidrs() {
    return this.cidrs;
  }
  public String getCidr(int index) {
    return this.cidrs.get(index);
  }
  public String getFirstCidr() {
    return this.cidrs.get(0);
  }
  public String getLastCidr() {
    return this.cidrs.get(cidrs.size() - 1);
  }
  public String getMatchingCidr(Predicate<String> predicate) {
    for (String item: cidrs) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingCidr(Predicate<String> predicate) {
    for (String item: cidrs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCidrs(List<String> cidrs) {
    if (cidrs != null) {this.cidrs = new ArrayList(); for (String item : cidrs){this.addToCidrs(item);}} else { this.cidrs = null;} return (A) this;
  }
  public A withCidrs(java.lang.String... cidrs) {
    if (this.cidrs != null) {this.cidrs.clear(); _visitables.remove("cidrs"); }
    if (cidrs != null) {for (String item :cidrs){ this.addToCidrs(item);}} return (A) this;
  }
  public Boolean hasCidrs() {
    return cidrs != null && !cidrs.isEmpty();
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RawIPSetFluentImpl that = (RawIPSetFluentImpl) o;
    if (!java.util.Objects.equals(cidrs, that.cidrs)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(source, that.source)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidrs,  name,  source,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidrs != null && !cidrs.isEmpty()) { sb.append("cidrs:"); sb.append(cidrs + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  
}
